summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--TAO/ChangeLogs/ChangeLog-02a122
-rw-r--r--TAO/tao/LocalObject.cpp62
-rw-r--r--TAO/tao/LocalObject.h106
-rw-r--r--TAO/tao/LocalObject.i129
-rw-r--r--TAO/tao/corbafwd.h13
5 files changed, 224 insertions, 208 deletions
diff --git a/TAO/ChangeLogs/ChangeLog-02a b/TAO/ChangeLogs/ChangeLog-02a
index aad0e36fc40..a017a96589c 100644
--- a/TAO/ChangeLogs/ChangeLog-02a
+++ b/TAO/ChangeLogs/ChangeLog-02a
@@ -1,84 +1,94 @@
+Sun Sep 10 04:03:54 2000 Nanbor Wang <nanbor@cs.wustl.edu>
+
+ * tao/corbafwd.h:
+ * tao/LocalObject.{h,i,cpp}: Changed class CORBA::LocalObject and
+ friends to CORBA_LocalObject and typedef the original names in
+ CORBA namespace instead. This change fix the compilation
+ problems in OMVS which seems to have problem dealing with nested
+ namespace. Thanks to <amoderni@viasoft.com> for reporting
+ this.
+
Fri Sep 8 21:33:02 2000 Jeff Parsons <parsons@cs.wustl.edu>
- * TAO_IDL/Makefile:
+ * TAO_IDL/Makefile:
- New file:
- * TAO_IDL/Makefile.dependencies:
+ New file:
+ * TAO_IDL/Makefile.dependencies:
- New simple makefile, called by the top level makefile for
- tao_idl, that touches (updates the timestamp) on the tao_idl
- executable if either the FE or the BE library has been modfied.
- Now that the IDL compiler is in three parts, this is necessary
- to cause code regeneration if _any_ part of the IDL compiler
- has been mofified. Thanks to Nanbor for his help with this.
- Note that a similiar scheme for Win32 platforms must still
- be put in place.
+ New simple makefile, called by the top level makefile for
+ tao_idl, that touches (updates the timestamp) on the tao_idl
+ executable if either the FE or the BE library has been modfied.
+ Now that the IDL compiler is in three parts, this is necessary
+ to cause code regeneration if _any_ part of the IDL compiler
+ has been mofified. Thanks to Nanbor for his help with this.
+ Note that a similiar scheme for Win32 platforms must still
+ be put in place.
Fri Sep 8 21:00:01 2000 Jeff Parsons <parsons@cs.wustl.edu>
- * TAO_IDL/ be/be_visitor_argument/arglist.cpp:
- * TAO_IDL/be/be_visitor_argument/request_info_arglist.cpp:
- * TAO_IDL/be/be_visitor_argument/request_info_ch.cpp:
- * TAO_IDL/be/be_visitor_argument/upcall_ss.cpp:
- * TAO_IDL/be/be_visitor_interface/interceptors_ch.cpp:
- * TAO_IDL/be/be_visitor_interface/interceptors_ss.cpp:
- * TAO_IDL/be/be_visitor_interface/interface_ss.cpp:
- * TAO_IDL/be/be_visitor_interface/thru_poa_collocated_ss.cpp:
- * TAO_IDL/be/be_visitor_operation/arglist.cpp:
- * TAO_IDL/be/be_visitor_operation/argument.cpp:
- * TAO_IDL/be/be_visitor_operation/interceptors_arglist.cpp:
- * TAO_IDL/be/be_visitor_operation/interceptors_ch.cpp:
- * TAO_IDL/be/be_visitor_operation/interceptors_cs.cpp:
- * TAO_IDL/be/be_visitor_operation/interceptors_exceptlist.cpp:
- * TAO_IDL/be/be_visitor_operation/interceptors_ss.cpp:
- * TAO_IDL/be/be_visitor_operation/operation_cs.cpp:
- * TAO_IDL/be/be_visitor_operation/operation_ss.cpp:
- * TAO_IDL/be/be_visitor_operation/thru_poa_collocated_ss.cpp:
-
- Started out as a fix of a bug reported by
- Christopher Kohlhoff <chris@kohlhoff.com>. If a nested portable
- interceptor class has a private member that's a pointer type (for
- example string), we generate the private member as char *&, but
- the constructor assigns a char * to this member. Some compilers
- complain about this. The reference seems unnecessary in this case,
- so it has been removed in the generated header file.
-
- There are also many cosmetic modifications to generated code,
- indenting, formatting, etc. in both stub and skeleton. Also
- cosmetic changes to IDL compiler source code.
+ * TAO_IDL/ be/be_visitor_argument/arglist.cpp:
+ * TAO_IDL/be/be_visitor_argument/request_info_arglist.cpp:
+ * TAO_IDL/be/be_visitor_argument/request_info_ch.cpp:
+ * TAO_IDL/be/be_visitor_argument/upcall_ss.cpp:
+ * TAO_IDL/be/be_visitor_interface/interceptors_ch.cpp:
+ * TAO_IDL/be/be_visitor_interface/interceptors_ss.cpp:
+ * TAO_IDL/be/be_visitor_interface/interface_ss.cpp:
+ * TAO_IDL/be/be_visitor_interface/thru_poa_collocated_ss.cpp:
+ * TAO_IDL/be/be_visitor_operation/arglist.cpp:
+ * TAO_IDL/be/be_visitor_operation/argument.cpp:
+ * TAO_IDL/be/be_visitor_operation/interceptors_arglist.cpp:
+ * TAO_IDL/be/be_visitor_operation/interceptors_ch.cpp:
+ * TAO_IDL/be/be_visitor_operation/interceptors_cs.cpp:
+ * TAO_IDL/be/be_visitor_operation/interceptors_exceptlist.cpp:
+ * TAO_IDL/be/be_visitor_operation/interceptors_ss.cpp:
+ * TAO_IDL/be/be_visitor_operation/operation_cs.cpp:
+ * TAO_IDL/be/be_visitor_operation/operation_ss.cpp:
+ * TAO_IDL/be/be_visitor_operation/thru_poa_collocated_ss.cpp:
+
+ Started out as a fix of a bug reported by
+ Christopher Kohlhoff <chris@kohlhoff.com>. If a nested portable
+ interceptor class has a private member that's a pointer type (for
+ example string), we generate the private member as char *&, but
+ the constructor assigns a char * to this member. Some compilers
+ complain about this. The reference seems unnecessary in this case,
+ so it has been removed in the generated header file.
+
+ There are also many cosmetic modifications to generated code,
+ indenting, formatting, etc. in both stub and skeleton. Also
+ cosmetic changes to IDL compiler source code.
Fri Sep 8 20:50:00 2000 Pradeep Gore <pradeep@cs.wustl.edu>
- * orbsvcs/orbsvcs/Notify/Notify_AdminProperties.h:
- * orbsvcs/orbsvcs/Notify/Notify_Worker_Task.h:
- Added virtual destructors.
- * orbsvcs/orbsvcs/Notify/Notify_Buffering_Strategy.cpp:
- Commented unused parameter.
+ * orbsvcs/orbsvcs/Notify/Notify_AdminProperties.h:
+ * orbsvcs/orbsvcs/Notify/Notify_Worker_Task.h:
+ Added virtual destructors.
+ * orbsvcs/orbsvcs/Notify/Notify_Buffering_Strategy.cpp:
+ Commented unused parameter.
Fri Sep 8 18:54:32 2000 Balachandran Natarajan <bala@cs.wustl.edu>
- * tao/Asynch_Reply_Dispatcher.cpp (TAO_Asynch_Reply_Dispatcher):
- * tao/Synch_Reply_Dispatcher.cpp: Initialised the reply_status_
- member in the constructor. Thanks to Ossama and his preying eyes
- for reporting this :-)
+ * tao/Asynch_Reply_Dispatcher.cpp (TAO_Asynch_Reply_Dispatcher):
+ * tao/Synch_Reply_Dispatcher.cpp: Initialised the reply_status_
+ member in the constructor. Thanks to Ossama and his preying eyes
+ for reporting this :-)
Fri Sep 8 17:35:01 2000 Balachandran Natarajan <bala@cs.wustl.edu>
- * Updated dependenices in orbsvcs
+ * Updated dependenices in orbsvcs
Fri Sep 8 17:24:00 2000 Balachandran Natarajan <bala@cs.wustl.edu>
- * Updated all the Makefiles in examples/*
+ * Updated all the Makefiles in examples/*
Fri Sep 8 16:58:37 2000 Balachandran Natarajan <bala@cs.wustl.edu>
- * Updated all the Makefiles in tests/*
+ * Updated all the Makefiles in tests/*
Fri Sep 8 16:18:33 2000 Balachandran Natarajan <bala@cs.wustl.edu>
- * tao/IORManipulation/TAO_IORManip.dsp:
- * tao/IORManipulation/TAO_IORManip_Static.dsp:
- * tao/TAO.dsw: Win32 project files
+ * tao/IORManipulation/TAO_IORManip.dsp:
+ * tao/IORManipulation/TAO_IORManip_Static.dsp:
+ * tao/TAO.dsw: Win32 project files
Fri Sep 8 15:51:52 2000 Balachandran Natarajan <bala@cs.wustl.edu>
diff --git a/TAO/tao/LocalObject.cpp b/TAO/tao/LocalObject.cpp
index bda9103ef3c..9186cee2922 100644
--- a/TAO/tao/LocalObject.cpp
+++ b/TAO/tao/LocalObject.cpp
@@ -19,18 +19,18 @@
ACE_RCSID(tao, LocalObject, "$Id$")
-CORBA::LocalObject::~LocalObject (void)
+CORBA_LocalObject::~CORBA_LocalObject (void)
{
}
void
-CORBA::LocalObject::_add_ref (void)
+CORBA_LocalObject::_add_ref (void)
{
// Do nothing as per CCM spec.
}
void
-CORBA::LocalObject::_remove_ref (void)
+CORBA_LocalObject::_remove_ref (void)
{
// Do nothing as per CCM spec.
}
@@ -39,8 +39,8 @@ CORBA::LocalObject::_remove_ref (void)
// create hash tables.
CORBA::ULong
-CORBA::LocalObject::_hash (CORBA::ULong /* maximum */,
- CORBA::Environment &ACE_TRY_ENV)
+CORBA_LocalObject::_hash (CORBA::ULong /* maximum */,
+ CORBA_Environment &ACE_TRY_ENV)
{
// @@ We need a different hash function here.
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), 0);
@@ -53,8 +53,8 @@ CORBA::LocalObject::_hash (CORBA::ULong /* maximum */,
// such as strcmp(), to allow more comparison algorithms.
CORBA::Boolean
-CORBA::LocalObject::_is_equivalent (CORBA::Object_ptr other_obj,
- CORBA::Environment &)
+CORBA_LocalObject::_is_equivalent (CORBA_Object_ptr other_obj,
+ CORBA_Environment &)
ACE_THROW_SPEC (())
{
return (other_obj == this) ? 1 : 0;
@@ -63,7 +63,7 @@ CORBA::LocalObject::_is_equivalent (CORBA::Object_ptr other_obj,
// TAO's extensions
TAO_ObjectKey *
-CORBA::LocalObject::_key (CORBA::Environment &ACE_TRY_ENV)
+CORBA_LocalObject::_key (CORBA_Environment &ACE_TRY_ENV)
{
ACE_ERROR((LM_ERROR, ACE_TEXT ("(%P|%t) Cannot get _key froma LocalObject!!!\n")));
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), 0);
@@ -71,17 +71,17 @@ CORBA::LocalObject::_key (CORBA::Environment &ACE_TRY_ENV)
#if 0
void *
-CORBA::LocalObject::_tao_QueryInterface (ptr_arith_t type)
+CORBA_LocalObject::_tao_QueryInterface (ptr_arith_t type)
{
void *retv = 0;
if (type == ACE_reinterpret_cast (ptr_arith_t,
- &CORBA::LocalObject::_narrow))
+ &CORBA_LocalObject::_narrow))
retv = ACE_reinterpret_cast (void *, this);
else if (type == ACE_reinterpret_cast (ptr_arith_t,
- &CORBA::Object::_narrow))
+ &CORBA_Object::_narrow))
retv = ACE_reinterpret_cast (void *,
- ACE_static_cast (CORBA::Object_ptr,
+ ACE_static_cast (CORBA_Object_ptr,
this));
if (retv)
this->_add_ref ();
@@ -97,25 +97,25 @@ CORBA::LocalObject::_tao_QueryInterface (ptr_arith_t type)
// the latter case, return FALSE.
CORBA::Boolean
-CORBA::LocalObject::_non_existent (CORBA::Environment &)
+CORBA_LocalObject::_non_existent (CORBA_Environment &)
{
return 0; // Always returns false.
}
void
-CORBA::LocalObject::_create_request (CORBA::Context_ptr,
+CORBA_LocalObject::_create_request (CORBA::Context_ptr,
const CORBA::Char *,
CORBA::NVList_ptr,
CORBA::NamedValue_ptr,
CORBA::Request_ptr &,
CORBA::Flags,
- CORBA::Environment &ACE_TRY_ENV)
+ CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW (CORBA::NO_IMPLEMENT ());
}
void
-CORBA::LocalObject::_create_request (CORBA::Context_ptr,
+CORBA_LocalObject::_create_request (CORBA::Context_ptr,
const CORBA::Char *,
CORBA::NVList_ptr,
CORBA::NamedValue_ptr,
@@ -123,28 +123,28 @@ CORBA::LocalObject::_create_request (CORBA::Context_ptr,
CORBA::ContextList_ptr,
CORBA::Request_ptr &,
CORBA::Flags,
- CORBA::Environment &ACE_TRY_ENV)
+ CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW (CORBA::NO_IMPLEMENT ());
}
CORBA::Request_ptr
-CORBA::LocalObject::_request (const CORBA::Char *,
- CORBA::Environment &ACE_TRY_ENV)
+CORBA_LocalObject::_request (const CORBA::Char *,
+ CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), CORBA::Request::_nil ());
}
#if (TAO_HAS_INTERFACE_REPOSITORY == 1)
IR_InterfaceDef_ptr
-CORBA::LocalObject::_get_interface (CORBA::Environment &ACE_TRY_ENV)
+CORBA_LocalObject::_get_interface (CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), 0);
}
#endif /* TAO_HAS_INTERFACE_REPOSITORY */
CORBA::ImplementationDef_ptr
-CORBA::LocalObject::_get_implementation (CORBA::Environment &ACE_TRY_ENV)
+CORBA_LocalObject::_get_implementation (CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), 0);
}
@@ -167,37 +167,37 @@ TAO_Local_RefCounted_Object::_remove_ref (void)
#if (TAO_HAS_CORBA_MESSAGING == 1)
CORBA::Policy_ptr
-CORBA::LocalObject::_get_policy (CORBA::PolicyType,
- CORBA::Environment &ACE_TRY_ENV)
+CORBA_LocalObject::_get_policy (CORBA::PolicyType,
+ CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), CORBA::Policy::_nil ());
}
CORBA::Policy_ptr
-CORBA::LocalObject::_get_client_policy (CORBA::PolicyType,
- CORBA::Environment &ACE_TRY_ENV)
+CORBA_LocalObject::_get_client_policy (CORBA::PolicyType,
+ CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), CORBA::Policy::_nil ());
}
CORBA::Object_ptr
-CORBA::LocalObject::_set_policy_overrides (const CORBA::PolicyList &,
+CORBA_LocalObject::_set_policy_overrides (const CORBA::PolicyList &,
CORBA::SetOverrideType,
- CORBA::Environment &ACE_TRY_ENV)
+ CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), CORBA::Policy::_nil ());
}
CORBA::PolicyList *
-CORBA::LocalObject::_get_policy_overrides (const CORBA::PolicyTypeSeq &,
- CORBA::Environment &ACE_TRY_ENV)
+CORBA_LocalObject::_get_policy_overrides (const CORBA::PolicyTypeSeq &,
+ CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), 0);
}
CORBA::Boolean
-CORBA::LocalObject::_validate_connection (CORBA::PolicyList_out,
- CORBA::Environment &ACE_TRY_ENV)
+CORBA_LocalObject::_validate_connection (CORBA::PolicyList_out,
+ CORBA_Environment &ACE_TRY_ENV)
{
ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), 0);
}
diff --git a/TAO/tao/LocalObject.i b/TAO/tao/LocalObject.i
index b21785dcf70..4ed53a54694 100644
--- a/TAO/tao/LocalObject.i
+++ b/TAO/tao/LocalObject.i
@@ -2,8 +2,8 @@
// ****************************************************************
-ACE_INLINE CORBA::LocalObject_ptr
-CORBA::LocalObject::_duplicate (CORBA::LocalObject_ptr obj)
+ACE_INLINE CORBA_LocalObject_ptr
+CORBA_LocalObject::_duplicate (CORBA_LocalObject_ptr obj)
{
if (obj)
obj->_add_ref ();
@@ -12,207 +12,208 @@ CORBA::LocalObject::_duplicate (CORBA::LocalObject_ptr obj)
// Null pointers represent nil objects.
-ACE_INLINE CORBA::LocalObject_ptr
-CORBA::LocalObject::_nil (void)
+ACE_INLINE CORBA_LocalObject_ptr
+CORBA_LocalObject::_nil (void)
{
return 0;
}
-ACE_INLINE CORBA::LocalObject_ptr
-CORBA::LocalObject::_narrow (CORBA::Object_ptr obj,
- CORBA::Environment&)
+ACE_INLINE CORBA_LocalObject_ptr
+CORBA_LocalObject::_narrow (CORBA_Object_ptr obj,
+ CORBA_Environment&)
{
if (obj->_is_local () != 0)
return
- ACE_reinterpret_cast (CORBA::LocalObject_ptr,
+ ACE_reinterpret_cast (CORBA_LocalObject_ptr,
obj->_tao_QueryInterface
(ACE_reinterpret_cast (ptr_arith_t,
- &CORBA::LocalObject::_narrow)));
+ &CORBA_LocalObject::_narrow)));
return 0;
}
-ACE_INLINE CORBA::LocalObject_ptr
-CORBA::LocalObject::_unchecked_narrow (CORBA::Object_ptr obj,
- CORBA::Environment&)
+ACE_INLINE CORBA_LocalObject_ptr
+CORBA_LocalObject::_unchecked_narrow (CORBA_Object_ptr obj,
+ CORBA_Environment&)
{
if (obj->_is_local () != 0)
return
- ACE_reinterpret_cast (CORBA::LocalObject_ptr,
+ ACE_reinterpret_cast (CORBA_LocalObject_ptr,
obj->_tao_QueryInterface
(ACE_reinterpret_cast (ptr_arith_t,
- &CORBA::LocalObject::_narrow)));
+ &CORBA_LocalObject::_narrow)));
return 0;
}
ACE_INLINE
-CORBA::LocalObject::LocalObject (void)
- : ACE_NESTED_CLASS (CORBA, Object (0))
+CORBA_LocalObject::CORBA_LocalObject (void)
+ : CORBA_Object (0)
{
}
ACE_INLINE
TAO_Local_RefCounted_Object::TAO_Local_RefCounted_Object (void)
- // : CORBA::LocalObject ()
+ // : CORBA_LocalObject ()
{
}
// *************************************************************
-// Inline operations for class CORBA::LocalObject_var
+// Inline operations for class CORBA_LocalObject_var
// *************************************************************
ACE_INLINE
-CORBA::LocalObject_var::LocalObject_var (void)
- : ptr_ (CORBA::LocalObject::_nil ())
+CORBA_LocalObject_var::CORBA_LocalObject_var (void)
+ : ptr_ (CORBA_LocalObject::_nil ())
{
}
ACE_INLINE
-CORBA::LocalObject_var::LocalObject_var (CORBA::LocalObject_ptr p)
+CORBA_LocalObject_var::CORBA_LocalObject_var (CORBA_LocalObject_ptr p)
: ptr_ (p)
{}
ACE_INLINE
-CORBA::LocalObject_var::~LocalObject_var (void)
+CORBA_LocalObject_var::~CORBA_LocalObject_var (void)
{
CORBA::release (this->ptr_);
}
-ACE_INLINE CORBA::LocalObject_ptr
-CORBA::LocalObject_var::ptr (void) const
+ACE_INLINE CORBA_LocalObject_ptr
+CORBA_LocalObject_var::ptr (void) const
{
return this->ptr_;
}
ACE_INLINE
-CORBA::LocalObject_var::LocalObject_var (const CORBA::LocalObject_var &p) // copy constructor
- : ptr_ (CORBA::LocalObject::_duplicate (p.ptr ()))
+CORBA_LocalObject_var::CORBA_LocalObject_var (const CORBA_LocalObject_var &p)
+ // copy constructor
+ : ptr_ (CORBA_LocalObject::_duplicate (p.ptr ()))
{}
-ACE_INLINE CORBA::LocalObject_var &
-CORBA::LocalObject_var::operator= (CORBA::LocalObject_ptr p)
+ACE_INLINE CORBA_LocalObject_var &
+CORBA_LocalObject_var::operator= (CORBA_LocalObject_ptr p)
{
CORBA::release (this->ptr_);
this->ptr_ = p;
return *this;
}
-ACE_INLINE CORBA::LocalObject_var &
-CORBA::LocalObject_var::operator= (const CORBA::LocalObject_var &p)
+ACE_INLINE CORBA_LocalObject_var &
+CORBA_LocalObject_var::operator= (const CORBA_LocalObject_var &p)
{
if (this != &p)
{
CORBA::release (this->ptr_);
- this->ptr_ = CORBA::LocalObject::_duplicate (p.ptr ());
+ this->ptr_ = CORBA_LocalObject::_duplicate (p.ptr ());
}
return *this;
}
ACE_INLINE
-CORBA::LocalObject_var::operator const CORBA::LocalObject_ptr &() const // cast
+CORBA_LocalObject_var::operator const CORBA_LocalObject_ptr &() const // cast
{
return this->ptr_;
}
ACE_INLINE
-CORBA::LocalObject_var::operator CORBA::LocalObject_ptr &() // cast
+CORBA_LocalObject_var::operator CORBA_LocalObject_ptr &() // cast
{
return this->ptr_;
}
-ACE_INLINE CORBA::LocalObject_ptr
-CORBA::LocalObject_var::operator-> (void) const
+ACE_INLINE CORBA_LocalObject_ptr
+CORBA_LocalObject_var::operator-> (void) const
{
return this->ptr_;
}
-ACE_INLINE CORBA::LocalObject_ptr
-CORBA::LocalObject_var::in (void) const
+ACE_INLINE CORBA_LocalObject_ptr
+CORBA_LocalObject_var::in (void) const
{
return this->ptr_;
}
-ACE_INLINE CORBA::LocalObject_ptr &
-CORBA::LocalObject_var::inout (void)
+ACE_INLINE CORBA_LocalObject_ptr &
+CORBA_LocalObject_var::inout (void)
{
return this->ptr_;
}
-ACE_INLINE CORBA::LocalObject_ptr &
-CORBA::LocalObject_var::out (void)
+ACE_INLINE CORBA_LocalObject_ptr &
+CORBA_LocalObject_var::out (void)
{
CORBA::release (this->ptr_);
- this->ptr_ = CORBA::LocalObject::_nil ();
+ this->ptr_ = CORBA_LocalObject::_nil ();
return this->ptr_;
}
-ACE_INLINE CORBA::LocalObject_ptr
-CORBA::LocalObject_var::_retn (void)
+ACE_INLINE CORBA_LocalObject_ptr
+CORBA_LocalObject_var::_retn (void)
{
// yield ownership of managed obj reference
- CORBA::LocalObject_ptr val = this->ptr_;
- this->ptr_ = CORBA::LocalObject::_nil ();
+ CORBA_LocalObject_ptr val = this->ptr_;
+ this->ptr_ = CORBA_LocalObject::_nil ();
return val;
}
// *************************************************************
-// Inline operations for class CORBA::LocalObject_out
+// Inline operations for class CORBA_LocalObject_out
// *************************************************************
ACE_INLINE
-CORBA::LocalObject_out::LocalObject_out (CORBA::LocalObject_ptr &p)
+CORBA_LocalObject_out::CORBA_LocalObject_out (CORBA_LocalObject_ptr &p)
: ptr_ (p)
{
- this->ptr_ = CORBA::LocalObject::_nil ();
+ this->ptr_ = CORBA_LocalObject::_nil ();
}
ACE_INLINE
-CORBA::LocalObject_out::LocalObject_out (CORBA::LocalObject_var &p) // constructor from _var
+CORBA_LocalObject_out::CORBA_LocalObject_out (CORBA_LocalObject_var &p) // constructor from _var
: ptr_ (p.out ())
{
CORBA::release (this->ptr_);
- this->ptr_ = CORBA::LocalObject::_nil ();
+ this->ptr_ = CORBA_LocalObject::_nil ();
}
ACE_INLINE
-CORBA::LocalObject_out::LocalObject_out (const CORBA::LocalObject_out &p) // copy constructor
+CORBA_LocalObject_out::CORBA_LocalObject_out (const CORBA_LocalObject_out &p) // copy constructor
: ptr_ (p.ptr_)
{}
-ACE_INLINE CORBA::LocalObject_out &
-CORBA::LocalObject_out::operator= (const CORBA::LocalObject_out &p)
+ACE_INLINE CORBA_LocalObject_out &
+CORBA_LocalObject_out::operator= (const CORBA_LocalObject_out &p)
{
this->ptr_ = p.ptr_;
return *this;
}
-ACE_INLINE CORBA::LocalObject_out &
-CORBA::LocalObject_out::operator= (const CORBA::LocalObject_var &p)
+ACE_INLINE CORBA_LocalObject_out &
+CORBA_LocalObject_out::operator= (const CORBA_LocalObject_var &p)
{
- this->ptr_ = CORBA::LocalObject::_duplicate (p.ptr ());
+ this->ptr_ = CORBA_LocalObject::_duplicate (p.ptr ());
return *this;
}
-ACE_INLINE CORBA::LocalObject_out &
-CORBA::LocalObject_out::operator= (CORBA::LocalObject_ptr p)
+ACE_INLINE CORBA_LocalObject_out &
+CORBA_LocalObject_out::operator= (CORBA_LocalObject_ptr p)
{
this->ptr_ = p;
return *this;
}
ACE_INLINE
-CORBA::LocalObject_out::operator CORBA::LocalObject_ptr &() // cast
+CORBA_LocalObject_out::operator CORBA_LocalObject_ptr &() // cast
{
return this->ptr_;
}
-ACE_INLINE CORBA::LocalObject_ptr &
-CORBA::LocalObject_out::ptr (void) // ptr
+ACE_INLINE CORBA_LocalObject_ptr &
+CORBA_LocalObject_out::ptr (void) // ptr
{
return this->ptr_;
}
-ACE_INLINE CORBA::LocalObject_ptr
-CORBA::LocalObject_out::operator-> (void)
+ACE_INLINE CORBA_LocalObject_ptr
+CORBA_LocalObject_out::operator-> (void)
{
return this->ptr_;
}
diff --git a/TAO/tao/corbafwd.h b/TAO/tao/corbafwd.h
index 9a05810e9a0..b378ba360a7 100644
--- a/TAO/tao/corbafwd.h
+++ b/TAO/tao/corbafwd.h
@@ -180,6 +180,11 @@ class CORBA_Object_var;
class CORBA_Object_out;
typedef class CORBA_Object *CORBA_Object_ptr;
+class CORBA_LocalObject;
+class CORBA_LocalObject_var;
+class CORBA_LocalObject_out;
+typedef class CORBA_LocalObject *CORBA_LocalObject_ptr;
+
class CORBA_Current;
class CORBA_Current_var;
class CORBA_Current_out;
@@ -461,10 +466,10 @@ TAO_NAMESPACE CORBA
typedef CORBA_Object_var Object_var;
typedef CORBA_Object_out Object_out;
- class LocalObject;
- typedef LocalObject *LocalObject_ptr;
- class LocalObject_var;
- class LocalObject_out;
+ typedef CORBA_LocalObject LocalObject;
+ typedef CORBA_LocalObject *LocalObject_ptr;
+ typedef CORBA_LocalObject_var LocalObject_var;
+ typedef CORBA_LocalObject_out LocalObject_out;
typedef CORBA_Principal Principal;
typedef CORBA_Principal *Principal_ptr;
diff --git a/TAO/tao/LocalObject.h b/TAO/tao/LocalObject.h
index d4b09eae114..2a011199f2a 100644
--- a/TAO/tao/LocalObject.h
+++ b/TAO/tao/LocalObject.h
@@ -31,32 +31,32 @@
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
-class TAO_Export CORBA::LocalObject : public virtual CORBA::Object
+class TAO_Export CORBA_LocalObject : public virtual CORBA_Object
{
// @@ NW: It is not clear whether minimum CORBA should support
// LocalObject or not. I think it should.
public:
- virtual ~LocalObject (void);
+ virtual ~CORBA_LocalObject (void);
// destructor
- static CORBA::LocalObject_ptr _duplicate (CORBA::LocalObject_ptr obj);
+ static CORBA_LocalObject_ptr _duplicate (CORBA_LocalObject_ptr obj);
// increment the ref count
- static CORBA::LocalObject_ptr _nil (void);
+ static CORBA_LocalObject_ptr _nil (void);
// return a NUL object
- static CORBA::LocalObject_ptr _narrow (CORBA::Object_ptr obj,
- CORBA_Environment &ACE_TRY_ENV =
- TAO_default_environment ());
- // @@ Narrowing a CORBA::LocalObject to a CORBA::Object is broken
- // right now. The solution seems to be making CORBA::Object an
- // abstract base class and create a CORBA::RemoteObject for regular
+ static CORBA_LocalObject_ptr _narrow (CORBA_Object_ptr obj,
+ CORBA_Environment &ACE_TRY_ENV =
+ TAO_default_environment ());
+ // @@ Narrowing a CORBA_LocalObject to a CORBA_Object is broken
+ // right now. The solution seems to be making CORBA_Object an
+ // abstract base class and create a CORBA_RemoteObject for regular
// object. Or, even easier, add a <is_local> member into
- // CORBA::Object. I'll take the easier route for now.
+ // CORBA_Object. I'll take the easier route for now.
- static CORBA::LocalObject_ptr _unchecked_narrow (CORBA::Object_ptr obj,
- CORBA_Environment &ACE_TRY_ENV =
- TAO_default_environment ());
+ static CORBA_LocalObject_ptr _unchecked_narrow (CORBA_Object_ptr obj,
+ CORBA_Environment &ACE_TRY_ENV =
+ TAO_default_environment ());
// no-op it is just here to simplify some templates.
#if (TAO_HAS_MINIMUM_CORBA == 0)
@@ -111,14 +111,14 @@ public:
CORBA::Policy_ptr _get_policy (
CORBA::PolicyType type,
- CORBA::Environment &ACE_TRY_ENV =
+ CORBA_Environment &ACE_TRY_ENV =
TAO_default_environment ()
);
// throws NO_IMPLEMENT.
CORBA::Policy_ptr _get_client_policy (
CORBA::PolicyType type,
- CORBA::Environment &ACE_TRY_ENV =
+ CORBA_Environment &ACE_TRY_ENV =
TAO_default_environment ()
);
// throws NO_IMPLEMENT.
@@ -126,21 +126,21 @@ public:
CORBA::Object_ptr _set_policy_overrides (
const CORBA::PolicyList & policies,
CORBA::SetOverrideType set_add,
- CORBA::Environment &ACE_TRY_ENV =
+ CORBA_Environment &ACE_TRY_ENV =
TAO_default_environment ()
);
// throws NO_IMPLEMENT.
CORBA::PolicyList * _get_policy_overrides (
const CORBA::PolicyTypeSeq & types,
- CORBA::Environment &ACE_TRY_ENV =
+ CORBA_Environment &ACE_TRY_ENV =
TAO_default_environment ()
);
// throws NO_IMPLEMENT.
CORBA::Boolean _validate_connection (
CORBA::PolicyList_out inconsistent_policies,
- CORBA::Environment &ACE_TRY_ENV =
+ CORBA_Environment &ACE_TRY_ENV =
TAO_default_environment ()
);
// throws NO_IMPLEMENT.
@@ -156,7 +156,7 @@ public:
// different ORB protocols are in use) there is no default
// implementation.
- virtual CORBA::Boolean _is_equivalent (CORBA::Object_ptr other_obj,
+ virtual CORBA::Boolean _is_equivalent (CORBA_Object_ptr other_obj,
CORBA_Environment &ACE_TRY_ENV =
TAO_default_environment ())
ACE_THROW_SPEC (());
@@ -190,13 +190,13 @@ public:
#endif /* 0 */
#if !defined(__GNUC__) || __GNUC__ > 2 || __GNUC_MINOR__ >= 8
- typedef CORBA::LocalObject_ptr _ptr_type;
- typedef CORBA::LocalObject_var _var_type;
+ typedef CORBA_LocalObject_ptr _ptr_type;
+ typedef CORBA_LocalObject_var _var_type;
#endif /* __GNUC__ */
// Useful for template programming.
protected:
- LocalObject (void);
+ CORBA_LocalObject (void);
// Default constructor. Make it protected to prevent instantiation
// of this class.
@@ -205,53 +205,53 @@ private:
// = Unimplemented methods
// constructor
- LocalObject (const LocalObject &);
- LocalObject &operator = (const LocalObject &);
+ CORBA_LocalObject (const CORBA_LocalObject &);
+ CORBA_LocalObject &operator = (const CORBA_LocalObject &);
};
-class TAO_Export CORBA::LocalObject_var
+class TAO_Export CORBA_LocalObject_var
{
public:
- LocalObject_var (void); // default constructor
- LocalObject_var (CORBA::LocalObject_ptr);
- LocalObject_var (const CORBA::LocalObject_var &); // copy constructor
- ~LocalObject_var (void); // destructor
+ CORBA_LocalObject_var (void); // default constructor
+ CORBA_LocalObject_var (CORBA_LocalObject_ptr);
+ CORBA_LocalObject_var (const CORBA_LocalObject_var &); // copy constructor
+ ~CORBA_LocalObject_var (void); // destructor
- LocalObject_var &operator= (CORBA::LocalObject_ptr);
- LocalObject_var &operator= (const CORBA::LocalObject_var &);
- CORBA::LocalObject_ptr operator-> (void) const;
+ CORBA_LocalObject_var &operator= (CORBA_LocalObject_ptr);
+ CORBA_LocalObject_var &operator= (const CORBA_LocalObject_var &);
+ CORBA_LocalObject_ptr operator-> (void) const;
- operator const CORBA::LocalObject_ptr &() const;
- operator CORBA::LocalObject_ptr &();
+ operator const CORBA_LocalObject_ptr &() const;
+ operator CORBA_LocalObject_ptr &();
// in, inout, out, _retn
- CORBA::LocalObject_ptr in (void) const;
- CORBA::LocalObject_ptr &inout (void);
- CORBA::LocalObject_ptr &out (void);
- CORBA::LocalObject_ptr _retn (void);
- CORBA::LocalObject_ptr ptr (void) const;
+ CORBA_LocalObject_ptr in (void) const;
+ CORBA_LocalObject_ptr &inout (void);
+ CORBA_LocalObject_ptr &out (void);
+ CORBA_LocalObject_ptr _retn (void);
+ CORBA_LocalObject_ptr ptr (void) const;
private:
- CORBA::LocalObject_ptr ptr_;
+ CORBA_LocalObject_ptr ptr_;
};
-class TAO_Export CORBA::LocalObject_out
+class TAO_Export CORBA_LocalObject_out
{
public:
- LocalObject_out (CORBA::LocalObject_ptr &);
- LocalObject_out (CORBA::LocalObject_var &);
- LocalObject_out (const CORBA::LocalObject_out &);
- LocalObject_out &operator= (const CORBA::LocalObject_out &);
- LocalObject_out &operator= (const CORBA::LocalObject_var &);
- LocalObject_out &operator= (CORBA::LocalObject_ptr);
- operator CORBA::LocalObject_ptr &();
- CORBA::LocalObject_ptr &ptr (void);
- CORBA::LocalObject_ptr operator-> (void);
+ CORBA_LocalObject_out (CORBA_LocalObject_ptr &);
+ CORBA_LocalObject_out (CORBA_LocalObject_var &);
+ CORBA_LocalObject_out (const CORBA_LocalObject_out &);
+ CORBA_LocalObject_out &operator= (const CORBA_LocalObject_out &);
+ CORBA_LocalObject_out &operator= (const CORBA_LocalObject_var &);
+ CORBA_LocalObject_out &operator= (CORBA_LocalObject_ptr);
+ operator CORBA_LocalObject_ptr &();
+ CORBA_LocalObject_ptr &ptr (void);
+ CORBA_LocalObject_ptr operator-> (void);
private:
- CORBA::LocalObject_ptr &ptr_;
+ CORBA_LocalObject_ptr &ptr_;
};
-class TAO_Export TAO_Local_RefCounted_Object : public virtual CORBA::LocalObject
+class TAO_Export TAO_Local_RefCounted_Object : public virtual CORBA_LocalObject
{
//
// This class adds default reference counting to local objects.